@@ -1,3 +1,5 @@
+__ASSAY__ = 'capture_rna'
+
 __STEPS__ = [
     'sample',
     'barcode',
@@ -6,4 +8,8 @@ __STEPS__ = [
     "featureCounts",
     "count_capture_rna",
     'analysis']
-__ASSAY__ = 'capture_rna'
\ No newline at end of file
+
+IMPORT_DICT = {
+    'star': 'celescope.rna',
+    'analysis': 'celescope.rna',
+}
\ No newline at end of file
