@@ -1,7 +1,9 @@
-__STEPS__ = [    
+__STEPS__ = [  
+    'mkref',  
     'sample',
     'barcode',
     'cutadapt',
+    'consensus',
     "star_virus",
     "count_capture_virus",
     "analysis_capture_virus",
