@@ -2,17 +2,11 @@
 # coding=utf8
 
 import os
-import sys
 import json
-import logging
-import re
-import numpy as np
 import pandas as pd
 import glob
-from scipy.io import mmwrite
-from scipy.sparse import csr_matrix
 from celescope.tools.report import reporter
-from celescope.tools.utils import *
+from celescope.tools.utils import add_log, s_common
 import celescope.tools
 
 toolsdir = os.path.dirname(celescope.tools.__file__)
@@ -72,7 +66,7 @@ def marker_table(marker_df):
     return html code
     """
     marker_df = marker_df.loc[:, ["cluster", "gene",
-                                  "avg_logFC", "pct.1", "pct.2", "p_val_adj"]]
+                                  "avg_log2FC", "pct.1", "pct.2", "p_val_adj"]]
     marker_gene_table = marker_df.to_html(
         escape=False,
         index=False,
